<?php
/**
 * The header for our theme
 *
 * @subpackage Wood Master
 * @since 1.0
 * @version 0.1
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
} else {
    do_action( 'wp_body_open' );
}?>

<a class="screen-reader-text skip-link" href="#skip-content"><?php esc_html_e( 'Skip to content', 'wood-master' ); ?></a>

<div id="header">
	<?php if (get_theme_mod('wood_master_hide_show_topbar',false) == true) {?>
		<div class="topbar">
			<div class="container">
				<div class="row">
					<div class="offset-lg-6 offset-md-5 col-lg-4 col-md-4 text-md-right text-center contacts align-self-end">
						<?php if(get_theme_mod('wood_master_topheader_phone_no')) {?>
							<a href="tel:<?php echo esc_attr(get_theme_mod('wood_master_topheader_phone_no')); ?>"><p class="callno mb-0 text-md-right text-center"><i class="fas fa-phone"></i><?php echo esc_html(get_theme_mod('wood_master_topheader_phone_no')); ?></p><span class="screen-reader-text"><?php echo esc_html(get_theme_mod('wood_master_topheader_phone_no')); ?></span></a>
						<?php }?>
					</div>
					<div class="col-lg-2 col-md-3">
						<div class="social-icons text-center">
							<?php if(get_theme_mod('wood_master_topheader_facebook_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('wood_master_topheader_facebook_url')); ?>"><i class="fab fa-facebook-f"></i><span class="screen-reader-text"><?php echo esc_html('Facebook', 'wood-master'); ?></span></a>
							<?php }?>
							<?php if(get_theme_mod('wood_master_topheader_twitter_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('wood_master_topheader_twitter_url')); ?>"><i class="fab fa-twitter"></i><span class="screen-reader-text"><?php echo esc_html('Twitter', 'wood-master'); ?></span></a>
							<?php }?>
							<?php if(get_theme_mod('wood_master_topheader_instagram_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('wood_master_topheader_instagram_url')); ?>"><i class="fab fa-instagram"></i><span class="screen-reader-text"><?php echo esc_html('Instagram', 'wood-master'); ?></span></a>
							<?php }?>
							<?php if(get_theme_mod('wood_master_topheader_linkedin_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('wood_master_topheader_linkedin_url')); ?>"><i class="fab fa-linkedin-in"></i><span class="screen-reader-text"><?php echo esc_html('Linkedin', 'wood-master'); ?></span></a>
							<?php }?>
						</div>
					</div>
				</div>
			</div>
		</div>
	<?php }?>
	<div class="bottom-header">
		<div class="container">
			<div class="menu-section">
				<div class="row mx-0">
					<div class="col-lg-3 col-md-4 col-9 outer-logo">
						<div class="logo">
							<?php if ( has_custom_logo() ) : ?>
			            		<?php the_custom_logo(); ?>
				            <?php endif; ?>
			             	<?php if (get_theme_mod('wood_master_show_site_title',true)) {?>
			          			<?php $blog_info = get_bloginfo( 'name' ); ?>
				                <?php if ( ! empty( $blog_info ) ) : ?>
				                  	<?php if ( is_front_page() && is_home() ) : ?>
				                    	<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				                  	<?php else : ?>
			                      		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
			                  		<?php endif; ?>
				                <?php endif; ?>
				            <?php }?>
				            <?php if (get_theme_mod('wood_master_show_tagline',true)) {?>
				                <?php
			                  		$description = get_bloginfo( 'description', 'display' );
				                  	if ( $description || is_customize_preview() ) :
				                ?>
			                  	<p class="site-description">
			                    	<?php echo esc_attr($description); ?>
			                  	</p>
			              		<?php endif; ?>
			          		<?php }?>
						</div>
					</div>
					<div class="col-lg-9 col-md-8 col-3 align-self-end menu-bar">
						<div class="toggle-menu responsive-menu">
							<?php if(has_nav_menu('primary')){ ?>
				            	<button onclick="wood_master_open()" role="tab" class="mobile-menu"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','wood-master'); ?></span></button>
				            <?php }?>
				        </div>
						<div id="sidelong-menu" class="nav sidenav">
			                <nav id="primary-site-navigation" class="nav-menu" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'wood-master' ); ?>">
			                  	<?php if(has_nav_menu('primary')){
				                    wp_nav_menu( array( 
										'theme_location' => 'primary',
										'container_class' => 'main-menu-navigation clearfix' ,
										'menu_class' => 'clearfix',
										'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
										'fallback_cb' => 'wp_page_menu',
				                    ) ); 
			                  	} ?>
			                  	<a href="javascript:void(0)" class="closebtn responsive-menu" onclick="wood_master_close()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','wood-master'); ?></span></a>
			                </nav>
			            </div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>

<?php if(is_singular()) {?>
	<div id="inner-pages-header">
		<div class="header-overlay"></div>
	    <div class="header-content">
		    <div class="container text-center"> 
		      	<h1><?php single_post_title(); ?></h1>
		      	<div class="theme-breadcrumb mt-3">
					<?php wood_master_breadcrumb();?>
				</div>
		    </div>
		</div>
	</div>
<?php } ?>